# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List

import httpx

from ..types import social_account_list_params, social_account_update_params, social_account_create_auth_url_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.social_account import SocialAccount
from ..types.social_account_list_response import SocialAccountListResponse
from ..types.social_account_disconnect_response import SocialAccountDisconnectResponse
from ..types.social_account_create_auth_url_response import SocialAccountCreateAuthURLResponse

__all__ = ["SocialAccountsResource", "AsyncSocialAccountsResource"]


class SocialAccountsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SocialAccountsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#accessing-raw-response-data-eg-headers
        """
        return SocialAccountsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SocialAccountsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#with_streaming_response
        """
        return SocialAccountsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialAccount:
        """
        Get social account by ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/v1/social-accounts/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialAccount,
        )

    def update(
        self,
        id: str,
        *,
        external_id: str | NotGiven = NOT_GIVEN,
        username: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialAccount:
        """
        Update social account

        Args:
          external_id: The platform's external id of the social account

          username: The platform's username of the social account

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._patch(
            f"/v1/social-accounts/{id}",
            body=maybe_transform(
                {
                    "external_id": external_id,
                    "username": username,
                },
                social_account_update_params.SocialAccountUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialAccount,
        )

    def list(
        self,
        *,
        id: List[str] | NotGiven = NOT_GIVEN,
        external_id: List[str] | NotGiven = NOT_GIVEN,
        limit: float | NotGiven = NOT_GIVEN,
        offset: float | NotGiven = NOT_GIVEN,
        platform: List[str] | NotGiven = NOT_GIVEN,
        username: List[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialAccountListResponse:
        """
        Get a paginated result for social accounts based on the applied filters

        Args:
          id: Filter by id(s). Multiple values imply OR logic (e.g.,
              ?id=spc_xxxxxx&id=spc_yyyyyy).

          external_id: Filter by externalId(s). Multiple values imply OR logic (e.g.,
              ?externalId=test&externalId=test2).

          limit: Number of items to return

          offset: Number of items to skip

          platform: Filter by platform(s). Multiple values imply OR logic (e.g.,
              ?platform=x&platform=facebook).

          username: Filter by username(s). Multiple values imply OR logic (e.g.,
              ?username=test&username=test2).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v1/social-accounts",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "id": id,
                        "external_id": external_id,
                        "limit": limit,
                        "offset": offset,
                        "platform": platform,
                        "username": username,
                    },
                    social_account_list_params.SocialAccountListParams,
                ),
            ),
            cast_to=SocialAccountListResponse,
        )

    def create_auth_url(
        self,
        *,
        platform: str,
        platform_data: social_account_create_auth_url_params.PlatformData | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialAccountCreateAuthURLResponse:
        """
        Generates a URL that initiates the authentication flow for a user's social media
        account. When visited, the user is redirected to the selected social platform's
        login/authorization page. Upon successful authentication, they are redirected
        back to your application

        Args:
          platform: The social account provider

          platform_data: Additional data needed for the provider

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/social-accounts/auth-url",
            body=maybe_transform(
                {
                    "platform": platform,
                    "platform_data": platform_data,
                },
                social_account_create_auth_url_params.SocialAccountCreateAuthURLParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialAccountCreateAuthURLResponse,
        )

    def disconnect(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialAccountDisconnectResponse:
        """
        Disconnecting an account with remove all auth tokens and mark the account as
        disconnected. The record of the account will be kept and can be retrieved and
        reconnected by the owner of the account.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._post(
            f"/v1/social-accounts/{id}/disconnect",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialAccountDisconnectResponse,
        )


class AsyncSocialAccountsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSocialAccountsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSocialAccountsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSocialAccountsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#with_streaming_response
        """
        return AsyncSocialAccountsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialAccount:
        """
        Get social account by ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/v1/social-accounts/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialAccount,
        )

    async def update(
        self,
        id: str,
        *,
        external_id: str | NotGiven = NOT_GIVEN,
        username: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialAccount:
        """
        Update social account

        Args:
          external_id: The platform's external id of the social account

          username: The platform's username of the social account

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._patch(
            f"/v1/social-accounts/{id}",
            body=await async_maybe_transform(
                {
                    "external_id": external_id,
                    "username": username,
                },
                social_account_update_params.SocialAccountUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialAccount,
        )

    async def list(
        self,
        *,
        id: List[str] | NotGiven = NOT_GIVEN,
        external_id: List[str] | NotGiven = NOT_GIVEN,
        limit: float | NotGiven = NOT_GIVEN,
        offset: float | NotGiven = NOT_GIVEN,
        platform: List[str] | NotGiven = NOT_GIVEN,
        username: List[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialAccountListResponse:
        """
        Get a paginated result for social accounts based on the applied filters

        Args:
          id: Filter by id(s). Multiple values imply OR logic (e.g.,
              ?id=spc_xxxxxx&id=spc_yyyyyy).

          external_id: Filter by externalId(s). Multiple values imply OR logic (e.g.,
              ?externalId=test&externalId=test2).

          limit: Number of items to return

          offset: Number of items to skip

          platform: Filter by platform(s). Multiple values imply OR logic (e.g.,
              ?platform=x&platform=facebook).

          username: Filter by username(s). Multiple values imply OR logic (e.g.,
              ?username=test&username=test2).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v1/social-accounts",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "id": id,
                        "external_id": external_id,
                        "limit": limit,
                        "offset": offset,
                        "platform": platform,
                        "username": username,
                    },
                    social_account_list_params.SocialAccountListParams,
                ),
            ),
            cast_to=SocialAccountListResponse,
        )

    async def create_auth_url(
        self,
        *,
        platform: str,
        platform_data: social_account_create_auth_url_params.PlatformData | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialAccountCreateAuthURLResponse:
        """
        Generates a URL that initiates the authentication flow for a user's social media
        account. When visited, the user is redirected to the selected social platform's
        login/authorization page. Upon successful authentication, they are redirected
        back to your application

        Args:
          platform: The social account provider

          platform_data: Additional data needed for the provider

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/social-accounts/auth-url",
            body=await async_maybe_transform(
                {
                    "platform": platform,
                    "platform_data": platform_data,
                },
                social_account_create_auth_url_params.SocialAccountCreateAuthURLParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialAccountCreateAuthURLResponse,
        )

    async def disconnect(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialAccountDisconnectResponse:
        """
        Disconnecting an account with remove all auth tokens and mark the account as
        disconnected. The record of the account will be kept and can be retrieved and
        reconnected by the owner of the account.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._post(
            f"/v1/social-accounts/{id}/disconnect",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialAccountDisconnectResponse,
        )


class SocialAccountsResourceWithRawResponse:
    def __init__(self, social_accounts: SocialAccountsResource) -> None:
        self._social_accounts = social_accounts

        self.retrieve = to_raw_response_wrapper(
            social_accounts.retrieve,
        )
        self.update = to_raw_response_wrapper(
            social_accounts.update,
        )
        self.list = to_raw_response_wrapper(
            social_accounts.list,
        )
        self.create_auth_url = to_raw_response_wrapper(
            social_accounts.create_auth_url,
        )
        self.disconnect = to_raw_response_wrapper(
            social_accounts.disconnect,
        )


class AsyncSocialAccountsResourceWithRawResponse:
    def __init__(self, social_accounts: AsyncSocialAccountsResource) -> None:
        self._social_accounts = social_accounts

        self.retrieve = async_to_raw_response_wrapper(
            social_accounts.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            social_accounts.update,
        )
        self.list = async_to_raw_response_wrapper(
            social_accounts.list,
        )
        self.create_auth_url = async_to_raw_response_wrapper(
            social_accounts.create_auth_url,
        )
        self.disconnect = async_to_raw_response_wrapper(
            social_accounts.disconnect,
        )


class SocialAccountsResourceWithStreamingResponse:
    def __init__(self, social_accounts: SocialAccountsResource) -> None:
        self._social_accounts = social_accounts

        self.retrieve = to_streamed_response_wrapper(
            social_accounts.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            social_accounts.update,
        )
        self.list = to_streamed_response_wrapper(
            social_accounts.list,
        )
        self.create_auth_url = to_streamed_response_wrapper(
            social_accounts.create_auth_url,
        )
        self.disconnect = to_streamed_response_wrapper(
            social_accounts.disconnect,
        )


class AsyncSocialAccountsResourceWithStreamingResponse:
    def __init__(self, social_accounts: AsyncSocialAccountsResource) -> None:
        self._social_accounts = social_accounts

        self.retrieve = async_to_streamed_response_wrapper(
            social_accounts.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            social_accounts.update,
        )
        self.list = async_to_streamed_response_wrapper(
            social_accounts.list,
        )
        self.create_auth_url = async_to_streamed_response_wrapper(
            social_accounts.create_auth_url,
        )
        self.disconnect = async_to_streamed_response_wrapper(
            social_accounts.disconnect,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["SocialPostDeleteResponse"]


class SocialPostDeleteResponse(BaseModel):
    success: bool
    """Whether or not the entity was deleted"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable, Optional
from datetime import datetime
from typing_extensions import Literal

import httpx

from ..types import social_post_list_params, social_post_create_params, social_post_update_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.social_post import SocialPost
from ..types.social_post_list_response import SocialPostListResponse
from ..types.social_post_delete_response import SocialPostDeleteResponse

__all__ = ["SocialPostsResource", "AsyncSocialPostsResource"]


class SocialPostsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SocialPostsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#accessing-raw-response-data-eg-headers
        """
        return SocialPostsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SocialPostsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#with_streaming_response
        """
        return SocialPostsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        caption: str,
        social_accounts: List[str],
        account_configurations: Optional[Iterable[social_post_create_params.AccountConfiguration]]
        | NotGiven = NOT_GIVEN,
        external_id: Optional[str] | NotGiven = NOT_GIVEN,
        is_draft: Optional[bool] | NotGiven = NOT_GIVEN,
        media: Optional[Iterable[social_post_create_params.Media]] | NotGiven = NOT_GIVEN,
        platform_configurations: Optional[social_post_create_params.PlatformConfigurations] | NotGiven = NOT_GIVEN,
        scheduled_at: Union[str, datetime, None] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPost:
        """
        Create Post

        Args:
          caption: Caption text for the post

          social_accounts: Array of social account IDs for posting

          account_configurations: Account-specific configurations for the post

          external_id: Array of social account IDs for posting

          is_draft: If isDraft is set then the post will not be processed

          media: Array of media URLs associated with the post

          platform_configurations: Platform-specific configurations for the post

          scheduled_at: Scheduled date and time for the post, setting to null or undefined will post
              instantly

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/social-posts",
            body=maybe_transform(
                {
                    "caption": caption,
                    "social_accounts": social_accounts,
                    "account_configurations": account_configurations,
                    "external_id": external_id,
                    "is_draft": is_draft,
                    "media": media,
                    "platform_configurations": platform_configurations,
                    "scheduled_at": scheduled_at,
                },
                social_post_create_params.SocialPostCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialPost,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPost:
        """
        Get Post by ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/v1/social-posts/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialPost,
        )

    def update(
        self,
        id: str,
        *,
        caption: str,
        social_accounts: List[str],
        account_configurations: Optional[Iterable[social_post_update_params.AccountConfiguration]]
        | NotGiven = NOT_GIVEN,
        external_id: Optional[str] | NotGiven = NOT_GIVEN,
        is_draft: Optional[bool] | NotGiven = NOT_GIVEN,
        media: Optional[Iterable[social_post_update_params.Media]] | NotGiven = NOT_GIVEN,
        platform_configurations: Optional[social_post_update_params.PlatformConfigurations] | NotGiven = NOT_GIVEN,
        scheduled_at: Union[str, datetime, None] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPost:
        """
        Update Post

        Args:
          caption: Caption text for the post

          social_accounts: Array of social account IDs for posting

          account_configurations: Account-specific configurations for the post

          external_id: Array of social account IDs for posting

          is_draft: If isDraft is set then the post will not be processed

          media: Array of media URLs associated with the post

          platform_configurations: Platform-specific configurations for the post

          scheduled_at: Scheduled date and time for the post, setting to null or undefined will post
              instantly

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._put(
            f"/v1/social-posts/{id}",
            body=maybe_transform(
                {
                    "caption": caption,
                    "social_accounts": social_accounts,
                    "account_configurations": account_configurations,
                    "external_id": external_id,
                    "is_draft": is_draft,
                    "media": media,
                    "platform_configurations": platform_configurations,
                    "scheduled_at": scheduled_at,
                },
                social_post_update_params.SocialPostUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialPost,
        )

    def list(
        self,
        *,
        external_id: List[str] | NotGiven = NOT_GIVEN,
        limit: float | NotGiven = NOT_GIVEN,
        offset: float | NotGiven = NOT_GIVEN,
        platform: List[
            Literal["bluesky", "facebook", "instagram", "linkedin", "pinterest", "threads", "tiktok", "x", "youtube"]
        ]
        | NotGiven = NOT_GIVEN,
        status: List[Literal["draft", "scheduled", "processing", "processed"]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPostListResponse:
        """
        Get a paginated result for posts based on the applied filters

        Args:
          external_id: Filter by external ID. Multiple values imply OR logic.

          limit: Number of items to return

          offset: Number of items to skip

          platform: Filter by platforms. Multiple values imply OR logic.

          status: Filter by post status. Multiple values imply OR logic.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v1/social-posts",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "external_id": external_id,
                        "limit": limit,
                        "offset": offset,
                        "platform": platform,
                        "status": status,
                    },
                    social_post_list_params.SocialPostListParams,
                ),
            ),
            cast_to=SocialPostListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPostDeleteResponse:
        """
        Delete Post

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._delete(
            f"/v1/social-posts/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialPostDeleteResponse,
        )


class AsyncSocialPostsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSocialPostsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSocialPostsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSocialPostsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#with_streaming_response
        """
        return AsyncSocialPostsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        caption: str,
        social_accounts: List[str],
        account_configurations: Optional[Iterable[social_post_create_params.AccountConfiguration]]
        | NotGiven = NOT_GIVEN,
        external_id: Optional[str] | NotGiven = NOT_GIVEN,
        is_draft: Optional[bool] | NotGiven = NOT_GIVEN,
        media: Optional[Iterable[social_post_create_params.Media]] | NotGiven = NOT_GIVEN,
        platform_configurations: Optional[social_post_create_params.PlatformConfigurations] | NotGiven = NOT_GIVEN,
        scheduled_at: Union[str, datetime, None] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPost:
        """
        Create Post

        Args:
          caption: Caption text for the post

          social_accounts: Array of social account IDs for posting

          account_configurations: Account-specific configurations for the post

          external_id: Array of social account IDs for posting

          is_draft: If isDraft is set then the post will not be processed

          media: Array of media URLs associated with the post

          platform_configurations: Platform-specific configurations for the post

          scheduled_at: Scheduled date and time for the post, setting to null or undefined will post
              instantly

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/social-posts",
            body=await async_maybe_transform(
                {
                    "caption": caption,
                    "social_accounts": social_accounts,
                    "account_configurations": account_configurations,
                    "external_id": external_id,
                    "is_draft": is_draft,
                    "media": media,
                    "platform_configurations": platform_configurations,
                    "scheduled_at": scheduled_at,
                },
                social_post_create_params.SocialPostCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialPost,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPost:
        """
        Get Post by ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/v1/social-posts/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialPost,
        )

    async def update(
        self,
        id: str,
        *,
        caption: str,
        social_accounts: List[str],
        account_configurations: Optional[Iterable[social_post_update_params.AccountConfiguration]]
        | NotGiven = NOT_GIVEN,
        external_id: Optional[str] | NotGiven = NOT_GIVEN,
        is_draft: Optional[bool] | NotGiven = NOT_GIVEN,
        media: Optional[Iterable[social_post_update_params.Media]] | NotGiven = NOT_GIVEN,
        platform_configurations: Optional[social_post_update_params.PlatformConfigurations] | NotGiven = NOT_GIVEN,
        scheduled_at: Union[str, datetime, None] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPost:
        """
        Update Post

        Args:
          caption: Caption text for the post

          social_accounts: Array of social account IDs for posting

          account_configurations: Account-specific configurations for the post

          external_id: Array of social account IDs for posting

          is_draft: If isDraft is set then the post will not be processed

          media: Array of media URLs associated with the post

          platform_configurations: Platform-specific configurations for the post

          scheduled_at: Scheduled date and time for the post, setting to null or undefined will post
              instantly

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._put(
            f"/v1/social-posts/{id}",
            body=await async_maybe_transform(
                {
                    "caption": caption,
                    "social_accounts": social_accounts,
                    "account_configurations": account_configurations,
                    "external_id": external_id,
                    "is_draft": is_draft,
                    "media": media,
                    "platform_configurations": platform_configurations,
                    "scheduled_at": scheduled_at,
                },
                social_post_update_params.SocialPostUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialPost,
        )

    async def list(
        self,
        *,
        external_id: List[str] | NotGiven = NOT_GIVEN,
        limit: float | NotGiven = NOT_GIVEN,
        offset: float | NotGiven = NOT_GIVEN,
        platform: List[
            Literal["bluesky", "facebook", "instagram", "linkedin", "pinterest", "threads", "tiktok", "x", "youtube"]
        ]
        | NotGiven = NOT_GIVEN,
        status: List[Literal["draft", "scheduled", "processing", "processed"]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPostListResponse:
        """
        Get a paginated result for posts based on the applied filters

        Args:
          external_id: Filter by external ID. Multiple values imply OR logic.

          limit: Number of items to return

          offset: Number of items to skip

          platform: Filter by platforms. Multiple values imply OR logic.

          status: Filter by post status. Multiple values imply OR logic.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v1/social-posts",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "external_id": external_id,
                        "limit": limit,
                        "offset": offset,
                        "platform": platform,
                        "status": status,
                    },
                    social_post_list_params.SocialPostListParams,
                ),
            ),
            cast_to=SocialPostListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPostDeleteResponse:
        """
        Delete Post

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._delete(
            f"/v1/social-posts/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialPostDeleteResponse,
        )


class SocialPostsResourceWithRawResponse:
    def __init__(self, social_posts: SocialPostsResource) -> None:
        self._social_posts = social_posts

        self.create = to_raw_response_wrapper(
            social_posts.create,
        )
        self.retrieve = to_raw_response_wrapper(
            social_posts.retrieve,
        )
        self.update = to_raw_response_wrapper(
            social_posts.update,
        )
        self.list = to_raw_response_wrapper(
            social_posts.list,
        )
        self.delete = to_raw_response_wrapper(
            social_posts.delete,
        )


class AsyncSocialPostsResourceWithRawResponse:
    def __init__(self, social_posts: AsyncSocialPostsResource) -> None:
        self._social_posts = social_posts

        self.create = async_to_raw_response_wrapper(
            social_posts.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            social_posts.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            social_posts.update,
        )
        self.list = async_to_raw_response_wrapper(
            social_posts.list,
        )
        self.delete = async_to_raw_response_wrapper(
            social_posts.delete,
        )


class SocialPostsResourceWithStreamingResponse:
    def __init__(self, social_posts: SocialPostsResource) -> None:
        self._social_posts = social_posts

        self.create = to_streamed_response_wrapper(
            social_posts.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            social_posts.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            social_posts.update,
        )
        self.list = to_streamed_response_wrapper(
            social_posts.list,
        )
        self.delete = to_streamed_response_wrapper(
            social_posts.delete,
        )


class AsyncSocialPostsResourceWithStreamingResponse:
    def __init__(self, social_posts: AsyncSocialPostsResource) -> None:
        self._social_posts = social_posts

        self.create = async_to_streamed_response_wrapper(
            social_posts.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            social_posts.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            social_posts.update,
        )
        self.list = async_to_streamed_response_wrapper(
            social_posts.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            social_posts.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .media import (
    MediaResource,
    AsyncMediaResource,
    MediaResourceWithRawResponse,
    AsyncMediaResourceWithRawResponse,
    MediaResourceWithStreamingResponse,
    AsyncMediaResourceWithStreamingResponse,
)
from .social_posts import (
    SocialPostsResource,
    AsyncSocialPostsResource,
    SocialPostsResourceWithRawResponse,
    AsyncSocialPostsResourceWithRawResponse,
    SocialPostsResourceWithStreamingResponse,
    AsyncSocialPostsResourceWithStreamingResponse,
)
from .social_accounts import (
    SocialAccountsResource,
    AsyncSocialAccountsResource,
    SocialAccountsResourceWithRawResponse,
    AsyncSocialAccountsResourceWithRawResponse,
    SocialAccountsResourceWithStreamingResponse,
    AsyncSocialAccountsResourceWithStreamingResponse,
)
from .social_post_results import (
    SocialPostResultsResource,
    AsyncSocialPostResultsResource,
    SocialPostResultsResourceWithRawResponse,
    AsyncSocialPostResultsResourceWithRawResponse,
    SocialPostResultsResourceWithStreamingResponse,
    AsyncSocialPostResultsResourceWithStreamingResponse,
)

__all__ = [
    "MediaResource",
    "AsyncMediaResource",
    "MediaResourceWithRawResponse",
    "AsyncMediaResourceWithRawResponse",
    "MediaResourceWithStreamingResponse",
    "AsyncMediaResourceWithStreamingResponse",
    "SocialPostsResource",
    "AsyncSocialPostsResource",
    "SocialPostsResourceWithRawResponse",
    "AsyncSocialPostsResourceWithRawResponse",
    "SocialPostsResourceWithStreamingResponse",
    "AsyncSocialPostsResourceWithStreamingResponse",
    "SocialPostResultsResource",
    "AsyncSocialPostResultsResource",
    "SocialPostResultsResourceWithRawResponse",
    "AsyncSocialPostResultsResourceWithRawResponse",
    "SocialPostResultsResourceWithStreamingResponse",
    "AsyncSocialPostResultsResourceWithStreamingResponse",
    "SocialAccountsResource",
    "AsyncSocialAccountsResource",
    "SocialAccountsResourceWithRawResponse",
    "AsyncSocialAccountsResourceWithRawResponse",
    "SocialAccountsResourceWithStreamingResponse",
    "AsyncSocialAccountsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .social_post import SocialPost as SocialPost
from .social_account import SocialAccount as SocialAccount
from .social_post_result import SocialPostResult as SocialPostResult
from .social_post_list_params import SocialPostListParams as SocialPostListParams
from .social_post_create_params import SocialPostCreateParams as SocialPostCreateParams
from .social_post_list_response import SocialPostListResponse as SocialPostListResponse
from .social_post_update_params import SocialPostUpdateParams as SocialPostUpdateParams
from .social_account_list_params import SocialAccountListParams as SocialAccountListParams
from .tiktok_configuration_param import TiktokConfigurationParam as TiktokConfigurationParam
from .social_post_delete_response import SocialPostDeleteResponse as SocialPostDeleteResponse
from .social_account_list_response import SocialAccountListResponse as SocialAccountListResponse
from .social_account_update_params import SocialAccountUpdateParams as SocialAccountUpdateParams
from .social_post_result_list_params import SocialPostResultListParams as SocialPostResultListParams
from .media_create_upload_url_response import MediaCreateUploadURLResponse as MediaCreateUploadURLResponse
from .social_post_result_list_response import SocialPostResultListResponse as SocialPostResultListResponse
from .social_account_disconnect_response import SocialAccountDisconnectResponse as SocialAccountDisconnectResponse
from .social_account_create_auth_url_params import SocialAccountCreateAuthURLParams as SocialAccountCreateAuthURLParams
from .social_account_create_auth_url_response import (
    SocialAccountCreateAuthURLResponse as SocialAccountCreateAuthURLResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import TypedDict

__all__ = ["TiktokConfigurationParam"]


class TiktokConfigurationParam(TypedDict, total=False):
    allow_comment: Optional[bool]
    """Allow comments on TikTok"""

    allow_duet: Optional[bool]
    """Allow duets on TikTok"""

    allow_stitch: Optional[bool]
    """Allow stitch on TikTok"""

    caption: Optional[object]
    """Overrides the `caption` from the post"""

    disclose_branded_content: Optional[bool]
    """Disclose branded content on TikTok"""

    disclose_your_brand: Optional[bool]
    """Disclose your brand on TikTok"""

    is_ai_generated: Optional[bool]
    """Flag content as AI generated on TikTok"""

    media: Optional[List[str]]
    """Overrides the `media` from the post"""

    privacy_status: Optional[str]
    """Sets the privacy status for TikTok (private, public)"""

    title: Optional[str]
    """Overrides the `title` from the post"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable, Optional
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo
from .tiktok_configuration_param import TiktokConfigurationParam

__all__ = [
    "SocialPostCreateParams",
    "AccountConfiguration",
    "AccountConfigurationConfiguration",
    "Media",
    "PlatformConfigurations",
    "PlatformConfigurationsBluesky",
    "PlatformConfigurationsFacebook",
    "PlatformConfigurationsInstagram",
    "PlatformConfigurationsLinkedin",
    "PlatformConfigurationsPinterest",
    "PlatformConfigurationsThreads",
    "PlatformConfigurationsX",
    "PlatformConfigurationsYoutube",
]


class SocialPostCreateParams(TypedDict, total=False):
    caption: Required[str]
    """Caption text for the post"""

    social_accounts: Required[List[str]]
    """Array of social account IDs for posting"""

    account_configurations: Optional[Iterable[AccountConfiguration]]
    """Account-specific configurations for the post"""

    external_id: Optional[str]
    """Array of social account IDs for posting"""

    is_draft: Annotated[Optional[bool], PropertyInfo(alias="isDraft")]
    """If isDraft is set then the post will not be processed"""

    media: Optional[Iterable[Media]]
    """Array of media URLs associated with the post"""

    platform_configurations: Optional[PlatformConfigurations]
    """Platform-specific configurations for the post"""

    scheduled_at: Annotated[Union[str, datetime, None], PropertyInfo(format="iso8601")]
    """
    Scheduled date and time for the post, setting to null or undefined will post
    instantly
    """


class AccountConfigurationConfiguration(TypedDict, total=False):
    allow_comment: Optional[bool]
    """Allow comments on TikTok"""

    allow_duet: Optional[bool]
    """Allow duets on TikTok"""

    allow_stitch: Optional[bool]
    """Allow stitch on TikTok"""

    board_ids: Optional[List[str]]
    """Pinterest board IDs"""

    caption: Optional[object]
    """Overrides the `caption` from the post"""

    disclose_branded_content: Optional[bool]
    """Disclose branded content on TikTok"""

    disclose_your_brand: Optional[bool]
    """Disclose your brand on TikTok"""

    link: Optional[str]
    """Pinterest post link"""

    location: Optional[Literal["reels", "timeline"]]
    """Threads post location"""

    media: Optional[List[str]]
    """Overrides the `media` from the post"""

    privacy_status: Optional[str]
    """Sets the privacy status for TikTok (private, public)"""

    title: Optional[str]
    """Overrides the `title` from the post"""


class AccountConfiguration(TypedDict, total=False):
    configuration: Required[AccountConfigurationConfiguration]
    """Configuration for the social account"""

    social_account_id: Required[str]
    """ID of the social account, you want to apply the configuration to"""


class Media(TypedDict, total=False):
    url: Required[str]
    """Public URL of the media"""

    thumbnail_timestamp_ms: Optional[object]
    """Timestamp in milliseconds of frame to use as thumbnail for the media"""

    thumbnail_url: Optional[object]
    """Public URL of the thumbnail for the media"""


class PlatformConfigurationsBluesky(TypedDict, total=False):
    caption: Optional[object]
    """Overrides the `caption` from the post"""

    media: Optional[List[str]]
    """Overrides the `media` from the post"""


class PlatformConfigurationsFacebook(TypedDict, total=False):
    caption: Optional[object]
    """Overrides the `caption` from the post"""

    media: Optional[List[str]]
    """Overrides the `media` from the post"""


class PlatformConfigurationsInstagram(TypedDict, total=False):
    caption: Optional[object]
    """Overrides the `caption` from the post"""

    media: Optional[List[str]]
    """Overrides the `media` from the post"""


class PlatformConfigurationsLinkedin(TypedDict, total=False):
    caption: Optional[object]
    """Overrides the `caption` from the post"""

    media: Optional[List[str]]
    """Overrides the `media` from the post"""


class PlatformConfigurationsPinterest(TypedDict, total=False):
    board_ids: Optional[List[str]]
    """Pinterest board IDs"""

    caption: Optional[object]
    """Overrides the `caption` from the post"""

    link: Optional[str]
    """Pinterest post link"""

    media: Optional[List[str]]
    """Overrides the `media` from the post"""


class PlatformConfigurationsThreads(TypedDict, total=False):
    caption: Optional[object]
    """Overrides the `caption` from the post"""

    location: Optional[Literal["reels", "timeline"]]
    """Threads post location"""

    media: Optional[List[str]]
    """Overrides the `media` from the post"""


class PlatformConfigurationsX(TypedDict, total=False):
    caption: Optional[object]
    """Overrides the `caption` from the post"""

    media: Optional[List[str]]
    """Overrides the `media` from the post"""


class PlatformConfigurationsYoutube(TypedDict, total=False):
    caption: Optional[object]
    """Overrides the `caption` from the post"""

    media: Optional[List[str]]
    """Overrides the `media` from the post"""

    title: Optional[str]
    """Overrides the `title` from the post"""


class PlatformConfigurations(TypedDict, total=False):
    bluesky: Optional[PlatformConfigurationsBluesky]
    """Bluesky configuration"""

    facebook: Optional[PlatformConfigurationsFacebook]
    """Facebook configuration"""

    instagram: Optional[PlatformConfigurationsInstagram]
    """Instagram configuration"""

    linkedin: Optional[PlatformConfigurationsLinkedin]
    """LinkedIn configuration"""

    pinterest: Optional[PlatformConfigurationsPinterest]
    """Pinterest configuration"""

    threads: Optional[PlatformConfigurationsThreads]
    """Threads configuration"""

    tiktok: Optional[TiktokConfigurationParam]
    """TikTok configuration"""

    tiktok_business: Optional[TiktokConfigurationParam]
    """TikTok configuration"""

    x: Optional[PlatformConfigurationsX]
    """Twitter configuration"""

    youtube: Optional[PlatformConfigurationsYoutube]
    """YouTube configuration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["SocialAccount"]


class SocialAccount(BaseModel):
    id: str
    """The unique identifier of the social account"""

    access_token: str
    """The access token of the social account"""

    access_token_expires_at: datetime
    """The access token expiration date of the social account"""

    external_id: Optional[str] = None
    """The external id of the social account"""

    metadata: Optional[object] = None
    """The metadata of the social account"""

    platform: str
    """The platform of the social account"""

    refresh_token: Optional[str] = None
    """The refresh token of the social account"""

    refresh_token_expires_at: Optional[datetime] = None
    """The refresh token expiration date of the social account"""

    status: Literal["connected", "disconnected"]
    """Status of the account"""

    user_id: str
    """The platform's id of the social account"""

    username: Optional[str] = None
    """The platform's username of the social account"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List

import httpx

from ..types import social_post_result_list_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.social_post_result import SocialPostResult
from ..types.social_post_result_list_response import SocialPostResultListResponse

__all__ = ["SocialPostResultsResource", "AsyncSocialPostResultsResource"]


class SocialPostResultsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SocialPostResultsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#accessing-raw-response-data-eg-headers
        """
        return SocialPostResultsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SocialPostResultsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#with_streaming_response
        """
        return SocialPostResultsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPostResult:
        """
        Get post result by ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/v1/social-post-results/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialPostResult,
        )

    def list(
        self,
        *,
        limit: float | NotGiven = NOT_GIVEN,
        offset: float | NotGiven = NOT_GIVEN,
        platform: List[str] | NotGiven = NOT_GIVEN,
        post_id: List[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPostResultListResponse:
        """
        Get a paginated result for post results based on the applied filters

        Args:
          limit: Number of items to return

          offset: Number of items to skip

          platform: Filter by platform(s). Multiple values imply OR logic (e.g.,
              ?platform=x&platform=facebook).

          post_id: Filter by post IDs. Multiple values imply OR logic (e.g.,
              ?post_id=123&post_id=456).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v1/social-post-results",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "offset": offset,
                        "platform": platform,
                        "post_id": post_id,
                    },
                    social_post_result_list_params.SocialPostResultListParams,
                ),
            ),
            cast_to=SocialPostResultListResponse,
        )


class AsyncSocialPostResultsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSocialPostResultsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSocialPostResultsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSocialPostResultsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#with_streaming_response
        """
        return AsyncSocialPostResultsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPostResult:
        """
        Get post result by ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/v1/social-post-results/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SocialPostResult,
        )

    async def list(
        self,
        *,
        limit: float | NotGiven = NOT_GIVEN,
        offset: float | NotGiven = NOT_GIVEN,
        platform: List[str] | NotGiven = NOT_GIVEN,
        post_id: List[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SocialPostResultListResponse:
        """
        Get a paginated result for post results based on the applied filters

        Args:
          limit: Number of items to return

          offset: Number of items to skip

          platform: Filter by platform(s). Multiple values imply OR logic (e.g.,
              ?platform=x&platform=facebook).

          post_id: Filter by post IDs. Multiple values imply OR logic (e.g.,
              ?post_id=123&post_id=456).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v1/social-post-results",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "offset": offset,
                        "platform": platform,
                        "post_id": post_id,
                    },
                    social_post_result_list_params.SocialPostResultListParams,
                ),
            ),
            cast_to=SocialPostResultListResponse,
        )


class SocialPostResultsResourceWithRawResponse:
    def __init__(self, social_post_results: SocialPostResultsResource) -> None:
        self._social_post_results = social_post_results

        self.retrieve = to_raw_response_wrapper(
            social_post_results.retrieve,
        )
        self.list = to_raw_response_wrapper(
            social_post_results.list,
        )


class AsyncSocialPostResultsResourceWithRawResponse:
    def __init__(self, social_post_results: AsyncSocialPostResultsResource) -> None:
        self._social_post_results = social_post_results

        self.retrieve = async_to_raw_response_wrapper(
            social_post_results.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            social_post_results.list,
        )


class SocialPostResultsResourceWithStreamingResponse:
    def __init__(self, social_post_results: SocialPostResultsResource) -> None:
        self._social_post_results = social_post_results

        self.retrieve = to_streamed_response_wrapper(
            social_post_results.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            social_post_results.list,
        )


class AsyncSocialPostResultsResourceWithStreamingResponse:
    def __init__(self, social_post_results: AsyncSocialPostResultsResource) -> None:
        self._social_post_results = social_post_results

        self.retrieve = async_to_streamed_response_wrapper(
            social_post_results.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            social_post_results.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["SocialAccountUpdateParams"]


class SocialAccountUpdateParams(TypedDict, total=False):
    external_id: str
    """The platform's external id of the social account"""

    username: str
    """The platform's username of the social account"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import TypedDict

__all__ = ["SocialAccountListParams"]


class SocialAccountListParams(TypedDict, total=False):
    id: List[str]
    """Filter by id(s).

    Multiple values imply OR logic (e.g., ?id=spc_xxxxxx&id=spc_yyyyyy).
    """

    external_id: List[str]
    """Filter by externalId(s).

    Multiple values imply OR logic (e.g., ?externalId=test&externalId=test2).
    """

    limit: float
    """Number of items to return"""

    offset: float
    """Number of items to skip"""

    platform: List[str]
    """Filter by platform(s).

    Multiple values imply OR logic (e.g., ?platform=x&platform=facebook).
    """

    username: List[str]
    """Filter by username(s).

    Multiple values imply OR logic (e.g., ?username=test&username=test2).
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["SocialPost"]


class SocialPost(BaseModel):
    id: str
    """Unique identifier of the post"""

    account_configurations: Optional[List[object]] = None
    """Account-specific configurations for the post"""

    caption: str
    """Caption text for the post"""

    created_at: str
    """Timestamp when the post was created"""

    external_id: Optional[str] = None
    """Provided unique identifier of the post"""

    media: Optional[object] = None
    """Array of media URLs associated with the post"""

    platform_configurations: Optional[object] = None
    """Platform-specific configurations for the post"""

    scheduled_at: Optional[str] = None
    """Scheduled date and time for the post"""

    social_accounts: List[str]
    """Array of social account IDs for posting"""

    status: Literal["draft", "scheduled", "processing", "processed"]
    """Current status of the post: draft, processed, scheduled, or processing"""

    updated_at: str
    """Timestamp when the post was last updated"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["SocialAccountCreateAuthURLParams", "PlatformData", "PlatformDataBluesky", "PlatformDataLinkedin"]


class SocialAccountCreateAuthURLParams(TypedDict, total=False):
    platform: Required[str]
    """The social account provider"""

    platform_data: PlatformData
    """Additional data needed for the provider"""


class PlatformDataBluesky(TypedDict, total=False):
    app_password: Required[str]
    """The app password of the account"""

    handle: Required[str]
    """The handle of the account"""


class PlatformDataLinkedin(TypedDict, total=False):
    connection_type: Required[Literal["personal", "organization"]]
    """
    The type of connection; personal for posting on behalf of the user only,
    organization for posting on behalf of both an organization and the user
    """


class PlatformData(TypedDict, total=False):
    bluesky: PlatformDataBluesky
    """Additional data needed for connecting bluesky accounts"""

    linkedin: PlatformDataLinkedin
    """Additional data for connecting linkedin accounts"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import TypedDict

__all__ = ["SocialPostResultListParams"]


class SocialPostResultListParams(TypedDict, total=False):
    limit: float
    """Number of items to return"""

    offset: float
    """Number of items to skip"""

    platform: List[str]
    """Filter by platform(s).

    Multiple values imply OR logic (e.g., ?platform=x&platform=facebook).
    """

    post_id: List[str]
    """Filter by post IDs.

    Multiple values imply OR logic (e.g., ?post_id=123&post_id=456).
    """
